import { Box } from "@mui/material";
import { reorderQuestionVariants } from "@root/questions/actions";
import { type ReactNode } from "react";
import type { DropResult } from "react-beautiful-dnd";
import { DragDropContext, Droppable } from "react-beautiful-dnd";

type AnswerDraggableListProps = {
  questionId: string;
  variants: ReactNode;
};

export const AnswerDraggableList = ({
  questionId,
  variants,
}: AnswerDraggableListProps) => {
  const onDragEnd = ({ destination, source }: DropResult) => {
    if (destination) {
      reorderQuestionVariants(questionId, source.index, destination.index);
    }
  };

  return (
    <DragDropContext onDragEnd={onDragEnd}>
      <Droppable droppableId="droppable-answer-list">
        {(provided) => (
          <Box ref={provided.innerRef} {...provided.droppableProps}>
            {variants}
            {provided.placeholder}
          </Box>
        )}
      </Droppable>
    </DragDropContext>
  );
};
